pub struct ClientTestHarnessBuilder<C = Ready<()>, H = Ready<()>> {
connection_task: Option<C>,
heartbeat_task: Option<H>,
version: Option<Version>,
}Expand description
A builder for a Client and ClientTestHarness instance.
Mocked data is used to construct a real Client instance. The mocked data is initialized by
the ClientTestHarnessBuilder, and can be accessed and changed through the
ClientTestHarness.
Fields
connection_task: Option<C>heartbeat_task: Option<H>version: Option<Version>Implementations
Sourceimpl<C, H> ClientTestHarnessBuilder<C, H>
impl<C, H> ClientTestHarnessBuilder<C, H>
Sourcepub fn with_version(self, version: Version) -> Self
pub fn with_version(self, version: Version) -> Self
Configure the mocked version for the peer.
Sourcepub fn with_connection_task<NewC>(
self,
connection_task: NewC,
) -> ClientTestHarnessBuilder<NewC, H>
pub fn with_connection_task<NewC>( self, connection_task: NewC, ) -> ClientTestHarnessBuilder<NewC, H>
Configure the mock connection task future to use.
Sourcepub fn with_heartbeat_task<NewH>(
self,
heartbeat_task: NewH,
) -> ClientTestHarnessBuilder<C, NewH>
pub fn with_heartbeat_task<NewH>( self, heartbeat_task: NewH, ) -> ClientTestHarnessBuilder<C, NewH>
Configure the mock heartbeat task future to use.
Sourcepub fn finish(self) -> (Client, ClientTestHarness)
pub fn finish(self) -> (Client, ClientTestHarness)
Build a Client instance with the mocked data and a ClientTestHarness to track it.
Sourcefn spawn_background_task_or_fallback<T>(
task_future: Option<T>,
) -> (JoinHandle<()>, AbortHandle)
fn spawn_background_task_or_fallback<T>( task_future: Option<T>, ) -> (JoinHandle<()>, AbortHandle)
Spawn a mock background abortable task task_future if provided, or a fallback task
otherwise.
The fallback task lives as long as MAX_PEER_CONNECTION_TIME.
Sourcefn spawn_background_task<T>(task_future: T) -> (JoinHandle<()>, AbortHandle)
fn spawn_background_task<T>(task_future: T) -> (JoinHandle<()>, AbortHandle)
Spawn a mock background abortable task to run task_future.
fn spawn_background_task_or_fallback_with_result<T>( task_future: Option<T>, ) -> (JoinHandle<Result<(), BoxError>>, AbortHandle)
fn spawn_background_task_with_result<T>( task_future: T, ) -> (JoinHandle<Result<(), BoxError>>, AbortHandle)